# story-children-video-maker
**Descrição breve:** Edita video automaticamente a partir de N narrações, N videoclips, e 1 musica de fundo.

## Índice

- [Introdução](#introdução)
- [Instalação](#instalação)
  - [Pré-requisitos](#pré-requisitos)
  - [Configuração de path_history](#configuração-de-path_history)
  - [Instalando Dependências](#instalando-dependências)

## Introdução

[Em construlçai]

## Instalação

### Instale story-children-video-maker


```shell
pip install story-children-video-maker

```

### Configuração de path_history

Pelo menos uma vez é necessário implementar a função **utils.setup.config()** para definir o caminho.


```python
from story-children-video-maker.utils import setup

utils.setup.config()

```
### Pré-requisitos


- Python = "3.11+"

